@@ -57,7 +57,7 @@ class DeidentifyDataset:
     De-identifier for de-identifying dicom content with basic profile
     and custom dates and UIDs.
     """
-    lookup: LookupID = field(default=LookupID())
+    lookup: LookupID
 
     @staticmethod
     def get_date_elements(ds: Dataset) -> dict:
@@ -172,6 +172,8 @@ class DeidentifyDataset:
             deid_content = core.deidentify(deid_content)
         except AttributeError:
             pass
+        except ValueError:
+            pass
 
         deid_content = self.deidentify_dates(deid_content)  # de-identified dates (not times)
         x = deid_content
